Package: PHENTHAUproc
Title: Phenology Modelling of Thaumetopoea Processionea
Version: 1.1.2
Authors@R: c(
    person("Lorenz", "Bachfischer", email = "lorenz.bachfischer@posteo.de", role = c("aut", "cre")),
    person("Department of Forest Protection, FVA", email = "Waldschutz.FVA-BW@forst.bwl.de", role = c("fnd")))
Description: Methods to calculate and present 'PHENTHAUproc', an early warning and decision support system for hazard assessment and control of oak processionary moth (OPM) using local and spatial temperature data. It was created by Halbig et al. 2024 (<doi:10.1016/j.foreco.2023.121525>) at FVA (<https://www.fva-bw.de/en/homepage/>) Forest Research Institute Baden-Wuerttemberg, Germany and at BOKU - University of Natural Ressources and Life Sciences, Vienna, Austria.
License: MIT + file LICENSE
Encoding: UTF-8
Depends: R (>= 4.1.0)
Imports: grDevices, lubridate (>= 1.9), methods, rlang, stats, terra
        (>= 1.7), utils
Suggests: dplyr, ggplot2 (>= 3.4), knitr, rmarkdown, testthat (>=
        3.0.0), tidyterra (>= 0.4.0)
Config/testthat/edition: 3
VignetteBuilder: knitr
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-05-19 17:40:28 UTC; lorenz
Author: Lorenz Bachfischer [aut, cre],
  Department of Forest Protection, FVA [fnd]
Maintainer: Lorenz Bachfischer <lorenz.bachfischer@posteo.de>
Repository: CRAN
Date/Publication: 2026-05-19 18:00:02 UTC
Built: R 4.6.0; ; 2026-05-19 22:21:26 UTC; unix
