# Generated by roxygen2: do not edit by hand

export(convert_dwd_to_phenthau)
export(get_legend)
export(load_test)
export(mortality)
export(parameter)
export(phenology)
export(phenthau)
export(plot_date)
export(plot_stages)
export(plot_station_step)
importFrom(rlang,.data)
importFrom(stats,na.omit)
