
# PHENTHAUproc
## Phenology Modelling of Thaumetopoea Processionea

<!-- badges: start -->
<!-- badges: end -->

Methods to calculate and present 'PHENTHAUproc', an early warning and decision support system for hazard assessment and control of oak processionary moth (OPM) using local and spatial temperature data. It was created by Halbig et al. 2024 (<doi:10.1016/j.foreco.2023.121525>) at FVA (<https://www.fva-bw.de/en/homepage/>) Forest Research Institute Baden-Wuerttemberg, Germany and at BOKU - University of Natural Ressources and Life Sciences, Vienna, Austria.

## Installation

You can install the CRAN version directly or using the development version of PHENTHAUproc from [GitHub](https://github.com/) with:

``` r
#install.packages("PHENTHAUproc")

# install.packages("devtools")
devtools::install_github("bachfisch/PHENTHAUproc")
```

