test_that("convert_hour_to_meanminmax",{
  x <- load_test("hour")[1:48, c("date", "tmean")]
  x <- convert_df_to_srl(x)
  x <- convert_hour_to_meanminmax(x)

  tmean <- round(as.data.frame(x[["tmean"]]), 1)
  tmin  <- round(as.data.frame(x[["tmin"]]),  1)
  tmax  <- round(as.data.frame(x[["tmax"]]),  1)

  expect_equal(tmean[[1]], 21.4)
  expect_equal(tmean[[2]], 17.5)
  expect_equal(tmin[[1]],  18.8)
  expect_equal(tmin[[2]],  11.6)
  expect_equal(tmax[[1]],  24)
  expect_equal(tmax[[2]],  22)
})




