% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/load_test.R
\name{load_test}
\alias{load_test}
\title{Load test data}
\usage{
load_test(type = "SpatRaster")
}
\arguments{
\item{type}{character, either day/hour/SpatRaster/SpatRaster_hour/budswelling}
}
\value{
data.frame/SpatRaster list with test data
}
\description{
Load test data
}
\seealso{
Other Helper:
\code{\link[=call_function]{call_function()}},
\code{\link[=check_data_with_params]{check_data_with_params()}},
\code{\link[=check_dimension_and_time]{check_dimension_and_time()}},
\code{\link[=convert_dwd_to_phenthau]{convert_dwd_to_phenthau()}},
\code{\link[=get_date]{get_date()}},
\code{\link[=get_formalArgs]{get_formalArgs()}},
\code{\link[=get_time]{get_time()}},
\code{\link[=remove_false]{remove_false()}},
\code{\link[=set_attributes]{set_attributes()}},
\code{\link[=subset_time]{subset_time()}},
\code{\link[=timename]{timename()}}
}
\concept{Helper}
