% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/load_test.R
\name{load_test_hour}
\alias{load_test_hour}
\title{load dataframe - hourly tmean - Freiburg 2023}
\usage{
load_test_hour()
}
\description{
load dataframe - hourly tmean - Freiburg 2023
}
\keyword{internal}
